@@ -1,4 +1,5 @@
 from faker.providers.job import Provider as JobProvider
+from faker.providers.job.az_AZ import Provider as AzAzJobProvider
 from faker.providers.job.de_DE import Provider as DeDeJobProvider
 from faker.providers.job.el_GR import Provider as ElGrJobProvider
 from faker.providers.job.fr_FR import Provider as FrFrJobProvider
@@ -22,6 +23,14 @@ class TestJobProvider:
             assert faker.job() in JobProvider.jobs
 
 
+class TestAzAz:
+    """Test az_AZ job provider"""
+
+    def test_job(self, faker, num_samples):
+        for _ in range(num_samples):
+            assert faker.job() in AzAzJobProvider.jobs
+
+
 class TestJaJp:
     """Test ja_JP job provider"""
 
